<?php
$TRANSLATIONS = array(
"Could not load template" => "Não foi possível carregar o modelo",
"Saved" => "Salvo",
"Reset" => "Reiniciar",
"An error occurred" => "Ocorreu um erro",
"Sharing email - public link shares (HTML)" => "Compartilhando email - link de compartilhamento público (HTML)",
"Sharing email - public link shares (plain text fallback)" => "Compartilhando email - link de compartilhamento público (alternativa em texto simples)",
"Sharing email (HTML)" => "Compartilhando email (HTML)",
"Sharing email (plain text fallback)" => "Compartilhando email (recurso texto simples)",
"Lost password mail" => "Perdeu senha do email",
"New user email (HTML)" => "Novo e-mail do usuário (HTML)",
"New user email (plain text fallback)" => "Novo e-mail do usuário (fallback texto simples)",
"Activity notification mail" => "Email de notificação de Atividade",
"Mail Templates" => "Modelos de Email",
"Theme" => "Tema",
"Template" => "Modelo",
"Please choose a template" => "Por favor, escolha um modelo",
"Save" => "Salvar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
